# py-logto
API references for Logto services. To learn more about how to interact with Logto APIs, see [Interact with Management API](https://docs.logto.io/docs/recipes/interact-with-management-api/).

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: Cloud
- Package version: 1.0.0
- Generator version: 7.5.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.9+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/Housain-maina/py-logto.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/Housain-maina/py-logto.git`)

Then import the package:
```python
import py_logto
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import py_logto
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import py_logto
from py_logto.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://passport.pyla.africa
# See configuration.py for a list of all supported configuration parameters.
configuration = py_logto.Configuration(
    host = "https://passport.pyla.africa"
)



# Enter a context with an instance of the API client
with py_logto.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = py_logto.ApplicationsApi(api_client)
    application_id = 'application_id_example' # str | The unique identifier of the application.
    page = 1 # int | Page number (starts from 1). (optional) (default to 1)
    page_size = 20 # int | Entries per page. (optional) (default to 20)

    try:
        # Get application API resource roles
        api_response = api_instance.api_applications_application_id_roles_get(application_id, page=page, page_size=page_size)
        print("The response of ApplicationsApi->api_applications_application_id_roles_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApplicationsApi->api_applications_application_id_roles_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://passport.pyla.africa*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationsApi* | [**api_applications_application_id_roles_get**](docs/ApplicationsApi.md#api_applications_application_id_roles_get) | **GET** /api/applications/{applicationId}/roles | Get application API resource roles
*ApplicationsApi* | [**api_applications_application_id_roles_post**](docs/ApplicationsApi.md#api_applications_application_id_roles_post) | **POST** /api/applications/{applicationId}/roles | Assign API resource roles to application
*ApplicationsApi* | [**api_applications_application_id_roles_put**](docs/ApplicationsApi.md#api_applications_application_id_roles_put) | **PUT** /api/applications/{applicationId}/roles | Update API resource roles for application
*ApplicationsApi* | [**api_applications_application_id_roles_role_id_delete**](docs/ApplicationsApi.md#api_applications_application_id_roles_role_id_delete) | **DELETE** /api/applications/{applicationId}/roles/{roleId} | Remove a API resource role from application
*ApplicationsApi* | [**api_applications_application_id_sign_in_experience_get**](docs/ApplicationsApi.md#api_applications_application_id_sign_in_experience_get) | **GET** /api/applications/{applicationId}/sign-in-experience | Get the application level sign-in experience
*ApplicationsApi* | [**api_applications_application_id_sign_in_experience_put**](docs/ApplicationsApi.md#api_applications_application_id_sign_in_experience_put) | **PUT** /api/applications/{applicationId}/sign-in-experience | Update application level sign-in experience
*ApplicationsApi* | [**api_applications_application_id_user_consent_scopes_get**](docs/ApplicationsApi.md#api_applications_application_id_user_consent_scopes_get) | **GET** /api/applications/{applicationId}/user-consent-scopes | List all the user consent scopes of an application.
*ApplicationsApi* | [**api_applications_application_id_user_consent_scopes_post**](docs/ApplicationsApi.md#api_applications_application_id_user_consent_scopes_post) | **POST** /api/applications/{applicationId}/user-consent-scopes | Assign user consent scopes to application.
*ApplicationsApi* | [**api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete**](docs/ApplicationsApi.md#api_applications_application_id_user_consent_scopes_scope_type_scope_id_delete) | **DELETE** /api/applications/{applicationId}/user-consent-scopes/{scopeType}/{scopeId} | Remove user consent scope from application.
*ApplicationsApi* | [**api_applications_get**](docs/ApplicationsApi.md#api_applications_get) | **GET** /api/applications | Get applications
*ApplicationsApi* | [**api_applications_id_delete**](docs/ApplicationsApi.md#api_applications_id_delete) | **DELETE** /api/applications/{id} | Delete application
*ApplicationsApi* | [**api_applications_id_get**](docs/ApplicationsApi.md#api_applications_id_get) | **GET** /api/applications/{id} | Get application
*ApplicationsApi* | [**api_applications_id_patch**](docs/ApplicationsApi.md#api_applications_id_patch) | **PATCH** /api/applications/{id} | Update application
*ApplicationsApi* | [**api_applications_id_protected_app_metadata_custom_domains_domain_delete**](docs/ApplicationsApi.md#api_applications_id_protected_app_metadata_custom_domains_domain_delete) | **DELETE** /api/applications/{id}/protected-app-metadata/custom-domains/{domain} | Delete a custom domain.
*ApplicationsApi* | [**api_applications_id_protected_app_metadata_custom_domains_get**](docs/ApplicationsApi.md#api_applications_id_protected_app_metadata_custom_domains_get) | **GET** /api/applications/{id}/protected-app-metadata/custom-domains | Get the list of custom domains of the protected application.
*ApplicationsApi* | [**api_applications_id_protected_app_metadata_custom_domains_post**](docs/ApplicationsApi.md#api_applications_id_protected_app_metadata_custom_domains_post) | **POST** /api/applications/{id}/protected-app-metadata/custom-domains | Add a custom domain to the protected application.
*ApplicationsApi* | [**api_applications_id_users_user_id_consent_organizations_get**](docs/ApplicationsApi.md#api_applications_id_users_user_id_consent_organizations_get) | **GET** /api/applications/{id}/users/{userId}/consent-organizations | List all the user consented organizations of a application.
*ApplicationsApi* | [**api_applications_id_users_user_id_consent_organizations_organization_id_delete**](docs/ApplicationsApi.md#api_applications_id_users_user_id_consent_organizations_organization_id_delete) | **DELETE** /api/applications/{id}/users/{userId}/consent-organizations/{organizationId} | Revoke a user&#39;s access to an organization for a application.
*ApplicationsApi* | [**api_applications_id_users_user_id_consent_organizations_post**](docs/ApplicationsApi.md#api_applications_id_users_user_id_consent_organizations_post) | **POST** /api/applications/{id}/users/{userId}/consent-organizations | Grant a list of organization access of a user for a application.
*ApplicationsApi* | [**api_applications_id_users_user_id_consent_organizations_put**](docs/ApplicationsApi.md#api_applications_id_users_user_id_consent_organizations_put) | **PUT** /api/applications/{id}/users/{userId}/consent-organizations | Grant a list of organization access of a user for a application.
*ApplicationsApi* | [**api_applications_post**](docs/ApplicationsApi.md#api_applications_post) | **POST** /api/applications | Create an application
*AuditLogsApi* | [**api_logs_get**](docs/AuditLogsApi.md#api_logs_get) | **GET** /api/logs | Get logs
*AuditLogsApi* | [**api_logs_id_get**](docs/AuditLogsApi.md#api_logs_id_get) | **GET** /api/logs/{id} | Get log
*AuthnApi* | [**api_authn_hasura_get**](docs/AuthnApi.md#api_authn_hasura_get) | **GET** /api/authn/hasura | Hasura auth hook endpoint
*AuthnApi* | [**api_authn_saml_connector_id_post**](docs/AuthnApi.md#api_authn_saml_connector_id_post) | **POST** /api/authn/saml/{connectorId} | SAML ACS endpoint (social)
*AuthnApi* | [**api_authn_single_sign_on_saml_connector_id_post**](docs/AuthnApi.md#api_authn_single_sign_on_saml_connector_id_post) | **POST** /api/authn/single-sign-on/saml/{connectorId} | SAML ACS endpoint (SSO)
*ConfigsApi* | [**api_configs_admin_console_get**](docs/ConfigsApi.md#api_configs_admin_console_get) | **GET** /api/configs/admin-console | Get admin console config
*ConfigsApi* | [**api_configs_admin_console_patch**](docs/ConfigsApi.md#api_configs_admin_console_patch) | **PATCH** /api/configs/admin-console | Update admin console config
*ConfigsApi* | [**api_configs_jwt_customizer_get**](docs/ConfigsApi.md#api_configs_jwt_customizer_get) | **GET** /api/configs/jwt-customizer | Get all JWT customizers
*ConfigsApi* | [**api_configs_jwt_customizer_token_type_path_delete**](docs/ConfigsApi.md#api_configs_jwt_customizer_token_type_path_delete) | **DELETE** /api/configs/jwt-customizer/{tokenTypePath} | Delete JWT customizer
*ConfigsApi* | [**api_configs_jwt_customizer_token_type_path_get**](docs/ConfigsApi.md#api_configs_jwt_customizer_token_type_path_get) | **GET** /api/configs/jwt-customizer/{tokenTypePath} | Get JWT customizer
*ConfigsApi* | [**api_configs_jwt_customizer_token_type_path_patch**](docs/ConfigsApi.md#api_configs_jwt_customizer_token_type_path_patch) | **PATCH** /api/configs/jwt-customizer/{tokenTypePath} | Update JWT customizer
*ConfigsApi* | [**api_configs_jwt_customizer_token_type_path_put**](docs/ConfigsApi.md#api_configs_jwt_customizer_token_type_path_put) | **PUT** /api/configs/jwt-customizer/{tokenTypePath} | Create or update JWT customizer
*ConfigsApi* | [**api_configs_oidc_key_type_get**](docs/ConfigsApi.md#api_configs_oidc_key_type_get) | **GET** /api/configs/oidc/{keyType} | Get OIDC keys
*ConfigsApi* | [**api_configs_oidc_key_type_key_id_delete**](docs/ConfigsApi.md#api_configs_oidc_key_type_key_id_delete) | **DELETE** /api/configs/oidc/{keyType}/{keyId} | Delete OIDC key
*ConfigsApi* | [**api_configs_oidc_key_type_rotate_post**](docs/ConfigsApi.md#api_configs_oidc_key_type_rotate_post) | **POST** /api/configs/oidc/{keyType}/rotate | Rotate OIDC keys
*ConnectorFactoriesApi* | [**api_connector_factories_get**](docs/ConnectorFactoriesApi.md#api_connector_factories_get) | **GET** /api/connector-factories | Get connector factories
*ConnectorFactoriesApi* | [**api_connector_factories_id_get**](docs/ConnectorFactoriesApi.md#api_connector_factories_id_get) | **GET** /api/connector-factories/{id} | Get connector factory
*ConnectorsApi* | [**api_connectors_connector_id_authorization_uri_post**](docs/ConnectorsApi.md#api_connectors_connector_id_authorization_uri_post) | **POST** /api/connectors/{connectorId}/authorization-uri | Get connector&#39;s authorization URI
*ConnectorsApi* | [**api_connectors_factory_id_test_post**](docs/ConnectorsApi.md#api_connectors_factory_id_test_post) | **POST** /api/connectors/{factoryId}/test | Test passwordless connector
*ConnectorsApi* | [**api_connectors_get**](docs/ConnectorsApi.md#api_connectors_get) | **GET** /api/connectors | Get connectors
*ConnectorsApi* | [**api_connectors_id_delete**](docs/ConnectorsApi.md#api_connectors_id_delete) | **DELETE** /api/connectors/{id} | Delete connector
*ConnectorsApi* | [**api_connectors_id_get**](docs/ConnectorsApi.md#api_connectors_id_get) | **GET** /api/connectors/{id} | Get connector
*ConnectorsApi* | [**api_connectors_id_patch**](docs/ConnectorsApi.md#api_connectors_id_patch) | **PATCH** /api/connectors/{id} | Update connector
*ConnectorsApi* | [**api_connectors_post**](docs/ConnectorsApi.md#api_connectors_post) | **POST** /api/connectors | Create connector
*CustomPhrasesApi* | [**api_custom_phrases_get**](docs/CustomPhrasesApi.md#api_custom_phrases_get) | **GET** /api/custom-phrases | Get all custom phrases
*CustomPhrasesApi* | [**api_custom_phrases_language_tag_delete**](docs/CustomPhrasesApi.md#api_custom_phrases_language_tag_delete) | **DELETE** /api/custom-phrases/{languageTag} | Delete custom phrase
*CustomPhrasesApi* | [**api_custom_phrases_language_tag_get**](docs/CustomPhrasesApi.md#api_custom_phrases_language_tag_get) | **GET** /api/custom-phrases/{languageTag} | Get custom phrases
*CustomPhrasesApi* | [**api_custom_phrases_language_tag_put**](docs/CustomPhrasesApi.md#api_custom_phrases_language_tag_put) | **PUT** /api/custom-phrases/{languageTag} | Upsert custom phrases
*DashboardApi* | [**api_dashboard_users_active_get**](docs/DashboardApi.md#api_dashboard_users_active_get) | **GET** /api/dashboard/users/active | Get active user data
*DashboardApi* | [**api_dashboard_users_new_get**](docs/DashboardApi.md#api_dashboard_users_new_get) | **GET** /api/dashboard/users/new | Get new user count
*DashboardApi* | [**api_dashboard_users_total_get**](docs/DashboardApi.md#api_dashboard_users_total_get) | **GET** /api/dashboard/users/total | Get total user count
*DomainsApi* | [**api_domains_get**](docs/DomainsApi.md#api_domains_get) | **GET** /api/domains | Get domains
*DomainsApi* | [**api_domains_id_delete**](docs/DomainsApi.md#api_domains_id_delete) | **DELETE** /api/domains/{id} | Delete domain
*DomainsApi* | [**api_domains_id_get**](docs/DomainsApi.md#api_domains_id_get) | **GET** /api/domains/{id} | Get domain
*DomainsApi* | [**api_domains_post**](docs/DomainsApi.md#api_domains_post) | **POST** /api/domains | Create domain
*HooksApi* | [**api_hooks_get**](docs/HooksApi.md#api_hooks_get) | **GET** /api/hooks | Get hooks
*HooksApi* | [**api_hooks_id_delete**](docs/HooksApi.md#api_hooks_id_delete) | **DELETE** /api/hooks/{id} | Delete hook
*HooksApi* | [**api_hooks_id_get**](docs/HooksApi.md#api_hooks_id_get) | **GET** /api/hooks/{id} | Get hook
*HooksApi* | [**api_hooks_id_patch**](docs/HooksApi.md#api_hooks_id_patch) | **PATCH** /api/hooks/{id} | Update hook
*HooksApi* | [**api_hooks_id_recent_logs_get**](docs/HooksApi.md#api_hooks_id_recent_logs_get) | **GET** /api/hooks/{id}/recent-logs | Get recent logs for a hook
*HooksApi* | [**api_hooks_id_signing_key_patch**](docs/HooksApi.md#api_hooks_id_signing_key_patch) | **PATCH** /api/hooks/{id}/signing-key | Update signing key for a hook
*HooksApi* | [**api_hooks_id_test_post**](docs/HooksApi.md#api_hooks_id_test_post) | **POST** /api/hooks/{id}/test | Test hook
*HooksApi* | [**api_hooks_post**](docs/HooksApi.md#api_hooks_post) | **POST** /api/hooks | Create a hook
*InteractionApi* | [**api_interaction_bind_mfa_post**](docs/InteractionApi.md#api_interaction_bind_mfa_post) | **POST** /api/interaction/bind-mfa | 
*InteractionApi* | [**api_interaction_consent_get**](docs/InteractionApi.md#api_interaction_consent_get) | **GET** /api/interaction/consent | 
*InteractionApi* | [**api_interaction_consent_post**](docs/InteractionApi.md#api_interaction_consent_post) | **POST** /api/interaction/consent | 
*InteractionApi* | [**api_interaction_delete**](docs/InteractionApi.md#api_interaction_delete) | **DELETE** /api/interaction | 
*InteractionApi* | [**api_interaction_event_put**](docs/InteractionApi.md#api_interaction_event_put) | **PUT** /api/interaction/event | 
*InteractionApi* | [**api_interaction_identifiers_patch**](docs/InteractionApi.md#api_interaction_identifiers_patch) | **PATCH** /api/interaction/identifiers | 
*InteractionApi* | [**api_interaction_mfa_put**](docs/InteractionApi.md#api_interaction_mfa_put) | **PUT** /api/interaction/mfa | 
*InteractionApi* | [**api_interaction_mfa_skipped_put**](docs/InteractionApi.md#api_interaction_mfa_skipped_put) | **PUT** /api/interaction/mfa-skipped | 
*InteractionApi* | [**api_interaction_profile_delete**](docs/InteractionApi.md#api_interaction_profile_delete) | **DELETE** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_profile_patch**](docs/InteractionApi.md#api_interaction_profile_patch) | **PATCH** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_profile_put**](docs/InteractionApi.md#api_interaction_profile_put) | **PUT** /api/interaction/profile | 
*InteractionApi* | [**api_interaction_put**](docs/InteractionApi.md#api_interaction_put) | **PUT** /api/interaction | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_authentication_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_authentication_post) | **POST** /api/interaction/single-sign-on/{connectorId}/authentication | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_authorization_url_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_authorization_url_post) | **POST** /api/interaction/single-sign-on/{connectorId}/authorization-url | 
*InteractionApi* | [**api_interaction_single_sign_on_connector_id_registration_post**](docs/InteractionApi.md#api_interaction_single_sign_on_connector_id_registration_post) | **POST** /api/interaction/single-sign-on/{connectorId}/registration | 
*InteractionApi* | [**api_interaction_single_sign_on_connectors_get**](docs/InteractionApi.md#api_interaction_single_sign_on_connectors_get) | **GET** /api/interaction/single-sign-on/connectors | 
*InteractionApi* | [**api_interaction_submit_post**](docs/InteractionApi.md#api_interaction_submit_post) | **POST** /api/interaction/submit | 
*InteractionApi* | [**api_interaction_verification_social_authorization_uri_post**](docs/InteractionApi.md#api_interaction_verification_social_authorization_uri_post) | **POST** /api/interaction/verification/social-authorization-uri | 
*InteractionApi* | [**api_interaction_verification_totp_post**](docs/InteractionApi.md#api_interaction_verification_totp_post) | **POST** /api/interaction/verification/totp | 
*InteractionApi* | [**api_interaction_verification_verification_code_post**](docs/InteractionApi.md#api_interaction_verification_verification_code_post) | **POST** /api/interaction/verification/verification-code | 
*InteractionApi* | [**api_interaction_verification_webauthn_authentication_post**](docs/InteractionApi.md#api_interaction_verification_webauthn_authentication_post) | **POST** /api/interaction/verification/webauthn-authentication | 
*InteractionApi* | [**api_interaction_verification_webauthn_registration_post**](docs/InteractionApi.md#api_interaction_verification_webauthn_registration_post) | **POST** /api/interaction/verification/webauthn-registration | 
*OrganizationRolesApi* | [**api_organization_roles_get**](docs/OrganizationRolesApi.md#api_organization_roles_get) | **GET** /api/organization-roles | Get organization roles
*OrganizationRolesApi* | [**api_organization_roles_id_delete**](docs/OrganizationRolesApi.md#api_organization_roles_id_delete) | **DELETE** /api/organization-roles/{id} | Delete organization role
*OrganizationRolesApi* | [**api_organization_roles_id_get**](docs/OrganizationRolesApi.md#api_organization_roles_id_get) | **GET** /api/organization-roles/{id} | Get organization role
*OrganizationRolesApi* | [**api_organization_roles_id_patch**](docs/OrganizationRolesApi.md#api_organization_roles_id_patch) | **PATCH** /api/organization-roles/{id} | Update organization role
*OrganizationRolesApi* | [**api_organization_roles_id_scopes_get**](docs/OrganizationRolesApi.md#api_organization_roles_id_scopes_get) | **GET** /api/organization-roles/{id}/scopes | Get organization role scopes
*OrganizationRolesApi* | [**api_organization_roles_id_scopes_organization_scope_id_delete**](docs/OrganizationRolesApi.md#api_organization_roles_id_scopes_organization_scope_id_delete) | **DELETE** /api/organization-roles/{id}/scopes/{organizationScopeId} | Remove organization scope
*OrganizationRolesApi* | [**api_organization_roles_id_scopes_post**](docs/OrganizationRolesApi.md#api_organization_roles_id_scopes_post) | **POST** /api/organization-roles/{id}/scopes | Assign organization scopes to organization role
*OrganizationRolesApi* | [**api_organization_roles_id_scopes_put**](docs/OrganizationRolesApi.md#api_organization_roles_id_scopes_put) | **PUT** /api/organization-roles/{id}/scopes | Replace organization scopes for organization role
*OrganizationRolesApi* | [**api_organization_roles_post**](docs/OrganizationRolesApi.md#api_organization_roles_post) | **POST** /api/organization-roles | Create an organization role
*OrganizationScopesApi* | [**api_organization_scopes_get**](docs/OrganizationScopesApi.md#api_organization_scopes_get) | **GET** /api/organization-scopes | Get organization scopes
*OrganizationScopesApi* | [**api_organization_scopes_id_delete**](docs/OrganizationScopesApi.md#api_organization_scopes_id_delete) | **DELETE** /api/organization-scopes/{id} | Delete organization scope
*OrganizationScopesApi* | [**api_organization_scopes_id_get**](docs/OrganizationScopesApi.md#api_organization_scopes_id_get) | **GET** /api/organization-scopes/{id} | Get organization scope
*OrganizationScopesApi* | [**api_organization_scopes_id_patch**](docs/OrganizationScopesApi.md#api_organization_scopes_id_patch) | **PATCH** /api/organization-scopes/{id} | Update organization scope
*OrganizationScopesApi* | [**api_organization_scopes_post**](docs/OrganizationScopesApi.md#api_organization_scopes_post) | **POST** /api/organization-scopes | Create an organization scope
*OrganizationsApi* | [**api_organizations_get**](docs/OrganizationsApi.md#api_organizations_get) | **GET** /api/organizations | Get organizations
*OrganizationsApi* | [**api_organizations_id_delete**](docs/OrganizationsApi.md#api_organizations_id_delete) | **DELETE** /api/organizations/{id} | Delete organization
*OrganizationsApi* | [**api_organizations_id_get**](docs/OrganizationsApi.md#api_organizations_id_get) | **GET** /api/organizations/{id} | Get organization
*OrganizationsApi* | [**api_organizations_id_patch**](docs/OrganizationsApi.md#api_organizations_id_patch) | **PATCH** /api/organizations/{id} | Update organization
*OrganizationsApi* | [**api_organizations_id_users_get**](docs/OrganizationsApi.md#api_organizations_id_users_get) | **GET** /api/organizations/{id}/users | Get organization user members
*OrganizationsApi* | [**api_organizations_id_users_post**](docs/OrganizationsApi.md#api_organizations_id_users_post) | **POST** /api/organizations/{id}/users | Add user members to organization
*OrganizationsApi* | [**api_organizations_id_users_put**](docs/OrganizationsApi.md#api_organizations_id_users_put) | **PUT** /api/organizations/{id}/users | Replace organization user members
*OrganizationsApi* | [**api_organizations_id_users_roles_post**](docs/OrganizationsApi.md#api_organizations_id_users_roles_post) | **POST** /api/organizations/{id}/users/roles | Assign roles to organization user members
*OrganizationsApi* | [**api_organizations_id_users_user_id_delete**](docs/OrganizationsApi.md#api_organizations_id_users_user_id_delete) | **DELETE** /api/organizations/{id}/users/{userId} | Remove user member from organization
*OrganizationsApi* | [**api_organizations_id_users_user_id_roles_get**](docs/OrganizationsApi.md#api_organizations_id_users_user_id_roles_get) | **GET** /api/organizations/{id}/users/{userId}/roles | Get roles for a user in an organization
*OrganizationsApi* | [**api_organizations_id_users_user_id_roles_post**](docs/OrganizationsApi.md#api_organizations_id_users_user_id_roles_post) | **POST** /api/organizations/{id}/users/{userId}/roles | Assign roles to a user in an organization
*OrganizationsApi* | [**api_organizations_id_users_user_id_roles_put**](docs/OrganizationsApi.md#api_organizations_id_users_user_id_roles_put) | **PUT** /api/organizations/{id}/users/{userId}/roles | Update roles for a user in an organization
*OrganizationsApi* | [**api_organizations_id_users_user_id_roles_role_id_delete**](docs/OrganizationsApi.md#api_organizations_id_users_user_id_roles_role_id_delete) | **DELETE** /api/organizations/{id}/users/{userId}/roles/{roleId} | Remove a role from a user in an organization
*OrganizationsApi* | [**api_organizations_post**](docs/OrganizationsApi.md#api_organizations_post) | **POST** /api/organizations | Create an organization
*ResourcesApi* | [**api_resources_get**](docs/ResourcesApi.md#api_resources_get) | **GET** /api/resources | Get API resources
*ResourcesApi* | [**api_resources_id_delete**](docs/ResourcesApi.md#api_resources_id_delete) | **DELETE** /api/resources/{id} | Delete API resource
*ResourcesApi* | [**api_resources_id_get**](docs/ResourcesApi.md#api_resources_id_get) | **GET** /api/resources/{id} | Get API resource
*ResourcesApi* | [**api_resources_id_is_default_patch**](docs/ResourcesApi.md#api_resources_id_is_default_patch) | **PATCH** /api/resources/{id}/is-default | Set API resource as default
*ResourcesApi* | [**api_resources_id_patch**](docs/ResourcesApi.md#api_resources_id_patch) | **PATCH** /api/resources/{id} | Update API resource
*ResourcesApi* | [**api_resources_post**](docs/ResourcesApi.md#api_resources_post) | **POST** /api/resources | Create an API resource
*ResourcesApi* | [**api_resources_resource_id_scopes_get**](docs/ResourcesApi.md#api_resources_resource_id_scopes_get) | **GET** /api/resources/{resourceId}/scopes | Get API resource scopes
*ResourcesApi* | [**api_resources_resource_id_scopes_post**](docs/ResourcesApi.md#api_resources_resource_id_scopes_post) | **POST** /api/resources/{resourceId}/scopes | Create API resource scope
*ResourcesApi* | [**api_resources_resource_id_scopes_scope_id_delete**](docs/ResourcesApi.md#api_resources_resource_id_scopes_scope_id_delete) | **DELETE** /api/resources/{resourceId}/scopes/{scopeId} | Delete API resource scope
*ResourcesApi* | [**api_resources_resource_id_scopes_scope_id_patch**](docs/ResourcesApi.md#api_resources_resource_id_scopes_scope_id_patch) | **PATCH** /api/resources/{resourceId}/scopes/{scopeId} | Update API resource scope
*RolesApi* | [**api_roles_get**](docs/RolesApi.md#api_roles_get) | **GET** /api/roles | Get roles
*RolesApi* | [**api_roles_id_applications_application_id_delete**](docs/RolesApi.md#api_roles_id_applications_application_id_delete) | **DELETE** /api/roles/{id}/applications/{applicationId} | Remove role from application
*RolesApi* | [**api_roles_id_applications_get**](docs/RolesApi.md#api_roles_id_applications_get) | **GET** /api/roles/{id}/applications | Get role applications
*RolesApi* | [**api_roles_id_applications_post**](docs/RolesApi.md#api_roles_id_applications_post) | **POST** /api/roles/{id}/applications | Assign role to applications
*RolesApi* | [**api_roles_id_delete**](docs/RolesApi.md#api_roles_id_delete) | **DELETE** /api/roles/{id} | Delete role
*RolesApi* | [**api_roles_id_get**](docs/RolesApi.md#api_roles_id_get) | **GET** /api/roles/{id} | Get role
*RolesApi* | [**api_roles_id_patch**](docs/RolesApi.md#api_roles_id_patch) | **PATCH** /api/roles/{id} | Update role
*RolesApi* | [**api_roles_id_scopes_get**](docs/RolesApi.md#api_roles_id_scopes_get) | **GET** /api/roles/{id}/scopes | Get role scopes
*RolesApi* | [**api_roles_id_scopes_post**](docs/RolesApi.md#api_roles_id_scopes_post) | **POST** /api/roles/{id}/scopes | Link scopes to role
*RolesApi* | [**api_roles_id_scopes_scope_id_delete**](docs/RolesApi.md#api_roles_id_scopes_scope_id_delete) | **DELETE** /api/roles/{id}/scopes/{scopeId} | Unlink scope from role
*RolesApi* | [**api_roles_id_users_get**](docs/RolesApi.md#api_roles_id_users_get) | **GET** /api/roles/{id}/users | Get role users
*RolesApi* | [**api_roles_id_users_post**](docs/RolesApi.md#api_roles_id_users_post) | **POST** /api/roles/{id}/users | Assign role to users
*RolesApi* | [**api_roles_id_users_user_id_delete**](docs/RolesApi.md#api_roles_id_users_user_id_delete) | **DELETE** /api/roles/{id}/users/{userId} | Remove role from user
*RolesApi* | [**api_roles_post**](docs/RolesApi.md#api_roles_post) | **POST** /api/roles | Create a role
*SSOConnectorProvidersApi* | [**api_sso_connector_providers_get**](docs/SSOConnectorProvidersApi.md#api_sso_connector_providers_get) | **GET** /api/sso-connector-providers | List all the supported SSO connector provider details
*SSOConnectorsApi* | [**api_sso_connectors_get**](docs/SSOConnectorsApi.md#api_sso_connectors_get) | **GET** /api/sso-connectors | List SSO connectors
*SSOConnectorsApi* | [**api_sso_connectors_id_delete**](docs/SSOConnectorsApi.md#api_sso_connectors_id_delete) | **DELETE** /api/sso-connectors/{id} | Delete SSO connector
*SSOConnectorsApi* | [**api_sso_connectors_id_get**](docs/SSOConnectorsApi.md#api_sso_connectors_id_get) | **GET** /api/sso-connectors/{id} | Get SSO connector
*SSOConnectorsApi* | [**api_sso_connectors_id_patch**](docs/SSOConnectorsApi.md#api_sso_connectors_id_patch) | **PATCH** /api/sso-connectors/{id} | Update SSO connector
*SSOConnectorsApi* | [**api_sso_connectors_post**](docs/SSOConnectorsApi.md#api_sso_connectors_post) | **POST** /api/sso-connectors | Create SSO connector
*SignInExperienceApi* | [**api_sign_in_exp_get**](docs/SignInExperienceApi.md#api_sign_in_exp_get) | **GET** /api/sign-in-exp | Get default sign-in experience settings
*SignInExperienceApi* | [**api_sign_in_exp_patch**](docs/SignInExperienceApi.md#api_sign_in_exp_patch) | **PATCH** /api/sign-in-exp | Update default sign-in experience settings
*StatusApi* | [**api_status_get**](docs/StatusApi.md#api_status_get) | **GET** /api/status | Health check
*SwaggerJsonApi* | [**api_swagger_json_get**](docs/SwaggerJsonApi.md#api_swagger_json_get) | **GET** /api/swagger.json | Get Swagger JSON
*SystemsApi* | [**api_systems_application_get**](docs/SystemsApi.md#api_systems_application_get) | **GET** /api/systems/application | Get the application constants.
*UserAssetsApi* | [**api_user_assets_post**](docs/UserAssetsApi.md#api_user_assets_post) | **POST** /api/user-assets | Upload asset
*UserAssetsApi* | [**api_user_assets_service_status_get**](docs/UserAssetsApi.md#api_user_assets_service_status_get) | **GET** /api/user-assets/service-status | Get service status
*UsersApi* | [**api_users_get**](docs/UsersApi.md#api_users_get) | **GET** /api/users | Get users
*UsersApi* | [**api_users_post**](docs/UsersApi.md#api_users_post) | **POST** /api/users | Create user
*UsersApi* | [**api_users_user_id_custom_data_get**](docs/UsersApi.md#api_users_user_id_custom_data_get) | **GET** /api/users/{userId}/custom-data | Get user custom data
*UsersApi* | [**api_users_user_id_custom_data_patch**](docs/UsersApi.md#api_users_user_id_custom_data_patch) | **PATCH** /api/users/{userId}/custom-data | Update user custom data
*UsersApi* | [**api_users_user_id_delete**](docs/UsersApi.md#api_users_user_id_delete) | **DELETE** /api/users/{userId} | Delete user
*UsersApi* | [**api_users_user_id_get**](docs/UsersApi.md#api_users_user_id_get) | **GET** /api/users/{userId} | Get user
*UsersApi* | [**api_users_user_id_has_password_get**](docs/UsersApi.md#api_users_user_id_has_password_get) | **GET** /api/users/{userId}/has-password | Check if user has password
*UsersApi* | [**api_users_user_id_identities_post**](docs/UsersApi.md#api_users_user_id_identities_post) | **POST** /api/users/{userId}/identities | Link social identity to user
*UsersApi* | [**api_users_user_id_identities_target_delete**](docs/UsersApi.md#api_users_user_id_identities_target_delete) | **DELETE** /api/users/{userId}/identities/{target} | Delete social identity from user
*UsersApi* | [**api_users_user_id_identities_target_put**](docs/UsersApi.md#api_users_user_id_identities_target_put) | **PUT** /api/users/{userId}/identities/{target} | Update social identity of user
*UsersApi* | [**api_users_user_id_is_suspended_patch**](docs/UsersApi.md#api_users_user_id_is_suspended_patch) | **PATCH** /api/users/{userId}/is-suspended | Update user suspension status
*UsersApi* | [**api_users_user_id_mfa_verifications_get**](docs/UsersApi.md#api_users_user_id_mfa_verifications_get) | **GET** /api/users/{userId}/mfa-verifications | Get user&#39;s MFA verifications
*UsersApi* | [**api_users_user_id_mfa_verifications_post**](docs/UsersApi.md#api_users_user_id_mfa_verifications_post) | **POST** /api/users/{userId}/mfa-verifications | Create an MFA verification for a user
*UsersApi* | [**api_users_user_id_mfa_verifications_verification_id_delete**](docs/UsersApi.md#api_users_user_id_mfa_verifications_verification_id_delete) | **DELETE** /api/users/{userId}/mfa-verifications/{verificationId} | Delete an MFA verification for a user
*UsersApi* | [**api_users_user_id_organizations_get**](docs/UsersApi.md#api_users_user_id_organizations_get) | **GET** /api/users/{userId}/organizations | Get organizations for a user
*UsersApi* | [**api_users_user_id_password_patch**](docs/UsersApi.md#api_users_user_id_password_patch) | **PATCH** /api/users/{userId}/password | Update user password
*UsersApi* | [**api_users_user_id_password_verify_post**](docs/UsersApi.md#api_users_user_id_password_verify_post) | **POST** /api/users/{userId}/password/verify | Verify user password
*UsersApi* | [**api_users_user_id_patch**](docs/UsersApi.md#api_users_user_id_patch) | **PATCH** /api/users/{userId} | Update user
*UsersApi* | [**api_users_user_id_profile_patch**](docs/UsersApi.md#api_users_user_id_profile_patch) | **PATCH** /api/users/{userId}/profile | Update user profile
*UsersApi* | [**api_users_user_id_roles_get**](docs/UsersApi.md#api_users_user_id_roles_get) | **GET** /api/users/{userId}/roles | Get roles for user
*UsersApi* | [**api_users_user_id_roles_post**](docs/UsersApi.md#api_users_user_id_roles_post) | **POST** /api/users/{userId}/roles | Assign roles to user
*UsersApi* | [**api_users_user_id_roles_put**](docs/UsersApi.md#api_users_user_id_roles_put) | **PUT** /api/users/{userId}/roles | Update roles for user
*UsersApi* | [**api_users_user_id_roles_role_id_delete**](docs/UsersApi.md#api_users_user_id_roles_role_id_delete) | **DELETE** /api/users/{userId}/roles/{roleId} | Remove role from user
*VerificationCodesApi* | [**api_verification_codes_post**](docs/VerificationCodesApi.md#api_verification_codes_post) | **POST** /api/verification-codes | Request and send a verification code
*VerificationCodesApi* | [**api_verification_codes_verify_post**](docs/VerificationCodesApi.md#api_verification_codes_verify_post) | **POST** /api/verification-codes/verify | Verify a verification code
*WellKnownApi* | [**api_well_known_phrases_get**](docs/WellKnownApi.md#api_well_known_phrases_get) | **GET** /api/.well-known/phrases | Get localized phrases
*WellKnownApi* | [**api_well_known_sign_in_exp_get**](docs/WellKnownApi.md#api_well_known_sign_in_exp_get) | **GET** /api/.well-known/sign-in-exp | Get full sign-in experience
*DefaultApi* | [**api_organization_invitations_get**](docs/DefaultApi.md#api_organization_invitations_get) | **GET** /api/organization-invitations | Get organization invitations
*DefaultApi* | [**api_organization_invitations_id_delete**](docs/DefaultApi.md#api_organization_invitations_id_delete) | **DELETE** /api/organization-invitations/{id} | Delete organization invitation
*DefaultApi* | [**api_organization_invitations_id_get**](docs/DefaultApi.md#api_organization_invitations_id_get) | **GET** /api/organization-invitations/{id} | Get organization invitation
*DefaultApi* | [**api_organization_invitations_id_message_post**](docs/DefaultApi.md#api_organization_invitations_id_message_post) | **POST** /api/organization-invitations/{id}/message | Resend invitation message
*DefaultApi* | [**api_organization_invitations_id_status_put**](docs/DefaultApi.md#api_organization_invitations_id_status_put) | **PUT** /api/organization-invitations/{id}/status | Update organization invitation status
*DefaultApi* | [**api_organization_invitations_post**](docs/DefaultApi.md#api_organization_invitations_post) | **POST** /api/organization-invitations | Create organization invitation
*DefaultApi* | [**api_organization_roles_id_resource_scopes_get**](docs/DefaultApi.md#api_organization_roles_id_resource_scopes_get) | **GET** /api/organization-roles/{id}/resource-scopes | Get organization role resource scopes
*DefaultApi* | [**api_organization_roles_id_resource_scopes_post**](docs/DefaultApi.md#api_organization_roles_id_resource_scopes_post) | **POST** /api/organization-roles/{id}/resource-scopes | Assign resource scopes to organization role
*DefaultApi* | [**api_organization_roles_id_resource_scopes_put**](docs/DefaultApi.md#api_organization_roles_id_resource_scopes_put) | **PUT** /api/organization-roles/{id}/resource-scopes | Replace resource scopes for organization role
*DefaultApi* | [**api_organization_roles_id_resource_scopes_scope_id_delete**](docs/DefaultApi.md#api_organization_roles_id_resource_scopes_scope_id_delete) | **DELETE** /api/organization-roles/{id}/resource-scopes/{scopeId} | Remove resource scope


## Documentation For Models

 - [ApiApplicationsApplicationIdRolesGet200ResponseInner](docs/ApiApplicationsApplicationIdRolesGet200ResponseInner.md)
 - [ApiApplicationsApplicationIdRolesPostRequest](docs/ApiApplicationsApplicationIdRolesPostRequest.md)
 - [ApiApplicationsApplicationIdRolesPutRequest](docs/ApiApplicationsApplicationIdRolesPutRequest.md)
 - [ApiApplicationsApplicationIdSignInExperienceGet200Response](docs/ApiApplicationsApplicationIdSignInExperienceGet200Response.md)
 - [ApiApplicationsApplicationIdSignInExperiencePutRequest](docs/ApiApplicationsApplicationIdSignInExperiencePutRequest.md)
 - [ApiApplicationsApplicationIdSignInExperiencePutRequestTermsOfUseUrl](docs/ApiApplicationsApplicationIdSignInExperiencePutRequestTermsOfUseUrl.md)
 - [ApiApplicationsApplicationIdUserConsentScopesGet200Response](docs/ApiApplicationsApplicationIdUserConsentScopesGet200Response.md)
 - [ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner](docs/ApiApplicationsApplicationIdUserConsentScopesGet200ResponseOrganizationScopesInner.md)
 - [ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInner](docs/ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInner.md)
 - [ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInnerResource](docs/ApiApplicationsApplicationIdUserConsentScopesGet200ResponseResourceScopesInnerResource.md)
 - [ApiApplicationsApplicationIdUserConsentScopesPostRequest](docs/ApiApplicationsApplicationIdUserConsentScopesPostRequest.md)
 - [ApiApplicationsGet200ResponseInner](docs/ApiApplicationsGet200ResponseInner.md)
 - [ApiApplicationsGet200ResponseInnerCustomClientMetadata](docs/ApiApplicationsGet200ResponseInnerCustomClientMetadata.md)
 - [ApiApplicationsGet200ResponseInnerOidcClientMetadata](docs/ApiApplicationsGet200ResponseInnerOidcClientMetadata.md)
 - [ApiApplicationsGet200ResponseInnerOidcClientMetadataRedirectUrisInner](docs/ApiApplicationsGet200ResponseInnerOidcClientMetadataRedirectUrisInner.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadata](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadata.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInner.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareData](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareData.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSsl](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSsl.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSslValidationErrorsInner](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerCloudflareDataSslValidationErrorsInner.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerDnsRecordsInner](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataCustomDomainsInnerDnsRecordsInner.md)
 - [ApiApplicationsGet200ResponseInnerProtectedAppMetadataPageRulesInner](docs/ApiApplicationsGet200ResponseInnerProtectedAppMetadataPageRulesInner.md)
 - [ApiApplicationsGetIsThirdPartyParameter](docs/ApiApplicationsGetIsThirdPartyParameter.md)
 - [ApiApplicationsGetTypesParameter](docs/ApiApplicationsGetTypesParameter.md)
 - [ApiApplicationsIdGet200Response](docs/ApiApplicationsIdGet200Response.md)
 - [ApiApplicationsIdPatchRequest](docs/ApiApplicationsIdPatchRequest.md)
 - [ApiApplicationsIdPatchRequestOidcClientMetadata](docs/ApiApplicationsIdPatchRequestOidcClientMetadata.md)
 - [ApiApplicationsIdPatchRequestProtectedAppMetadata](docs/ApiApplicationsIdPatchRequestProtectedAppMetadata.md)
 - [ApiApplicationsIdProtectedAppMetadataCustomDomainsPostRequest](docs/ApiApplicationsIdProtectedAppMetadataCustomDomainsPostRequest.md)
 - [ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response](docs/ApiApplicationsIdUsersUserIdConsentOrganizationsGet200Response.md)
 - [ApiApplicationsIdUsersUserIdConsentOrganizationsGet200ResponseOrganizationsInner](docs/ApiApplicationsIdUsersUserIdConsentOrganizationsGet200ResponseOrganizationsInner.md)
 - [ApiApplicationsIdUsersUserIdConsentOrganizationsPostRequest](docs/ApiApplicationsIdUsersUserIdConsentOrganizationsPostRequest.md)
 - [ApiApplicationsIdUsersUserIdConsentOrganizationsPutRequest](docs/ApiApplicationsIdUsersUserIdConsentOrganizationsPutRequest.md)
 - [ApiApplicationsPostRequest](docs/ApiApplicationsPostRequest.md)
 - [ApiApplicationsPostRequestProtectedAppMetadata](docs/ApiApplicationsPostRequestProtectedAppMetadata.md)
 - [ApiAuthnHasuraGet200Response](docs/ApiAuthnHasuraGet200Response.md)
 - [ApiAuthnSingleSignOnSamlConnectorIdPostRequest](docs/ApiAuthnSingleSignOnSamlConnectorIdPostRequest.md)
 - [ApiConfigsAdminConsoleGet200Response](docs/ApiConfigsAdminConsoleGet200Response.md)
 - [ApiConfigsAdminConsoleGet200ResponseCheckedChargeNotification](docs/ApiConfigsAdminConsoleGet200ResponseCheckedChargeNotification.md)
 - [ApiConfigsAdminConsoleGet200ResponseDevelopmentTenantMigrationNotification](docs/ApiConfigsAdminConsoleGet200ResponseDevelopmentTenantMigrationNotification.md)
 - [ApiConfigsAdminConsolePatchRequest](docs/ApiConfigsAdminConsolePatchRequest.md)
 - [ApiConfigsJwtCustomizerGet200ResponseInner](docs/ApiConfigsJwtCustomizerGet200ResponseInner.md)
 - [ApiConfigsJwtCustomizerGet200ResponseInnerOneOf](docs/ApiConfigsJwtCustomizerGet200ResponseInnerOneOf.md)
 - [ApiConfigsJwtCustomizerGet200ResponseInnerOneOf1](docs/ApiConfigsJwtCustomizerGet200ResponseInnerOneOf1.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200Response](docs/ApiConfigsJwtCustomizerTokenTypePathGet200Response.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1TokenSample](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOf1TokenSample.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSample](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSample.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUser.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserIdentitiesValue.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserOrganizationRolesInner](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserOrganizationRolesInner.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfile.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserProfileAddress.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInner](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInner.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInner](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInner.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserRolesInnerScopesInnerResource.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserSsoIdentitiesInner](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfContextSampleUserSsoIdentitiesInner.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSample](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSample.md)
 - [ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSampleAud](docs/ApiConfigsJwtCustomizerTokenTypePathGet200ResponseOneOfTokenSampleAud.md)
 - [ApiConfigsJwtCustomizerTokenTypePathPutRequest](docs/ApiConfigsJwtCustomizerTokenTypePathPutRequest.md)
 - [ApiConfigsOidcKeyTypeGet200ResponseInner](docs/ApiConfigsOidcKeyTypeGet200ResponseInner.md)
 - [ApiConfigsOidcKeyTypeRotatePostRequest](docs/ApiConfigsOidcKeyTypeRotatePostRequest.md)
 - [ApiConnectorFactoriesGet200ResponseInner](docs/ApiConnectorFactoriesGet200ResponseInner.md)
 - [ApiConnectorsConnectorIdAuthorizationUriPost200Response](docs/ApiConnectorsConnectorIdAuthorizationUriPost200Response.md)
 - [ApiConnectorsConnectorIdAuthorizationUriPostRequest](docs/ApiConnectorsConnectorIdAuthorizationUriPostRequest.md)
 - [ApiConnectorsFactoryIdTestPostRequest](docs/ApiConnectorsFactoryIdTestPostRequest.md)
 - [ApiConnectorsGet200ResponseInner](docs/ApiConnectorsGet200ResponseInner.md)
 - [ApiConnectorsGet200ResponseInnerFormItemsInner](docs/ApiConnectorsGet200ResponseInnerFormItemsInner.md)
 - [ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf](docs/ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf.md)
 - [ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf1](docs/ApiConnectorsGet200ResponseInnerFormItemsInnerOneOf1.md)
 - [ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfSelectItemsInner](docs/ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfSelectItemsInner.md)
 - [ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfShowConditionsInner](docs/ApiConnectorsGet200ResponseInnerFormItemsInnerOneOfShowConditionsInner.md)
 - [ApiConnectorsGet200ResponseInnerMetadata](docs/ApiConnectorsGet200ResponseInnerMetadata.md)
 - [ApiConnectorsIdPatchRequest](docs/ApiConnectorsIdPatchRequest.md)
 - [ApiConnectorsIdPatchRequestMetadata](docs/ApiConnectorsIdPatchRequestMetadata.md)
 - [ApiConnectorsPostRequest](docs/ApiConnectorsPostRequest.md)
 - [ApiConnectorsPostRequestMetadata](docs/ApiConnectorsPostRequestMetadata.md)
 - [ApiCustomPhrasesGet200ResponseInner](docs/ApiCustomPhrasesGet200ResponseInner.md)
 - [ApiDashboardUsersActiveGet200Response](docs/ApiDashboardUsersActiveGet200Response.md)
 - [ApiDashboardUsersActiveGet200ResponseDauCurveInner](docs/ApiDashboardUsersActiveGet200ResponseDauCurveInner.md)
 - [ApiDashboardUsersNewGet200Response](docs/ApiDashboardUsersNewGet200Response.md)
 - [ApiDashboardUsersNewGet200ResponseToday](docs/ApiDashboardUsersNewGet200ResponseToday.md)
 - [ApiDashboardUsersTotalGet200Response](docs/ApiDashboardUsersTotalGet200Response.md)
 - [ApiDomainsGet200ResponseInner](docs/ApiDomainsGet200ResponseInner.md)
 - [ApiDomainsPostRequest](docs/ApiDomainsPostRequest.md)
 - [ApiHooksGet200ResponseInner](docs/ApiHooksGet200ResponseInner.md)
 - [ApiHooksGet200ResponseInnerConfig](docs/ApiHooksGet200ResponseInnerConfig.md)
 - [ApiHooksGet200ResponseInnerExecutionStats](docs/ApiHooksGet200ResponseInnerExecutionStats.md)
 - [ApiHooksIdPatch200Response](docs/ApiHooksIdPatch200Response.md)
 - [ApiHooksIdPatchRequest](docs/ApiHooksIdPatchRequest.md)
 - [ApiHooksIdTestPostRequest](docs/ApiHooksIdTestPostRequest.md)
 - [ApiHooksIdTestPostRequestConfig](docs/ApiHooksIdTestPostRequestConfig.md)
 - [ApiHooksPostRequest](docs/ApiHooksPostRequest.md)
 - [ApiHooksPostRequestConfig](docs/ApiHooksPostRequestConfig.md)
 - [ApiInteractionBindMfaPostRequest](docs/ApiInteractionBindMfaPostRequest.md)
 - [ApiInteractionBindMfaPostRequestOneOf](docs/ApiInteractionBindMfaPostRequestOneOf.md)
 - [ApiInteractionBindMfaPostRequestOneOf1](docs/ApiInteractionBindMfaPostRequestOneOf1.md)
 - [ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResults](docs/ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResults.md)
 - [ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResultsCrepProps](docs/ApiInteractionBindMfaPostRequestOneOf1ClientExtensionResultsCrepProps.md)
 - [ApiInteractionBindMfaPostRequestOneOf1Response](docs/ApiInteractionBindMfaPostRequestOneOf1Response.md)
 - [ApiInteractionBindMfaPostRequestOneOf2](docs/ApiInteractionBindMfaPostRequestOneOf2.md)
 - [ApiInteractionConsentGet200Response](docs/ApiInteractionConsentGet200Response.md)
 - [ApiInteractionConsentGet200ResponseApplication](docs/ApiInteractionConsentGet200ResponseApplication.md)
 - [ApiInteractionConsentGet200ResponseApplicationBranding](docs/ApiInteractionConsentGet200ResponseApplicationBranding.md)
 - [ApiInteractionConsentGet200ResponseMissingResourceScopesInner](docs/ApiInteractionConsentGet200ResponseMissingResourceScopesInner.md)
 - [ApiInteractionConsentGet200ResponseMissingResourceScopesInnerResource](docs/ApiInteractionConsentGet200ResponseMissingResourceScopesInnerResource.md)
 - [ApiInteractionConsentGet200ResponseMissingResourceScopesInnerScopesInner](docs/ApiInteractionConsentGet200ResponseMissingResourceScopesInnerScopesInner.md)
 - [ApiInteractionConsentGet200ResponseOrganizationsInner](docs/ApiInteractionConsentGet200ResponseOrganizationsInner.md)
 - [ApiInteractionConsentGet200ResponseUser](docs/ApiInteractionConsentGet200ResponseUser.md)
 - [ApiInteractionConsentPostRequest](docs/ApiInteractionConsentPostRequest.md)
 - [ApiInteractionEventPutRequest](docs/ApiInteractionEventPutRequest.md)
 - [ApiInteractionMfaPutRequest](docs/ApiInteractionMfaPutRequest.md)
 - [ApiInteractionMfaPutRequestOneOf](docs/ApiInteractionMfaPutRequestOneOf.md)
 - [ApiInteractionMfaPutRequestOneOf1](docs/ApiInteractionMfaPutRequestOneOf1.md)
 - [ApiInteractionMfaPutRequestOneOfResponse](docs/ApiInteractionMfaPutRequestOneOfResponse.md)
 - [ApiInteractionMfaSkippedPutRequest](docs/ApiInteractionMfaSkippedPutRequest.md)
 - [ApiInteractionPutRequest](docs/ApiInteractionPutRequest.md)
 - [ApiInteractionPutRequestIdentifier](docs/ApiInteractionPutRequestIdentifier.md)
 - [ApiInteractionPutRequestIdentifierOneOf](docs/ApiInteractionPutRequestIdentifierOneOf.md)
 - [ApiInteractionPutRequestIdentifierOneOf1](docs/ApiInteractionPutRequestIdentifierOneOf1.md)
 - [ApiInteractionPutRequestIdentifierOneOf2](docs/ApiInteractionPutRequestIdentifierOneOf2.md)
 - [ApiInteractionPutRequestIdentifierOneOf3](docs/ApiInteractionPutRequestIdentifierOneOf3.md)
 - [ApiInteractionPutRequestIdentifierOneOf4](docs/ApiInteractionPutRequestIdentifierOneOf4.md)
 - [ApiInteractionPutRequestIdentifierOneOf5](docs/ApiInteractionPutRequestIdentifierOneOf5.md)
 - [ApiInteractionPutRequestIdentifierOneOf6](docs/ApiInteractionPutRequestIdentifierOneOf6.md)
 - [ApiInteractionPutRequestIdentifierOneOf7](docs/ApiInteractionPutRequestIdentifierOneOf7.md)
 - [ApiInteractionPutRequestProfile](docs/ApiInteractionPutRequestProfile.md)
 - [ApiInteractionSingleSignOnConnectorIdAuthorizationUrlPostRequest](docs/ApiInteractionSingleSignOnConnectorIdAuthorizationUrlPostRequest.md)
 - [ApiInteractionSubmitPost200Response](docs/ApiInteractionSubmitPost200Response.md)
 - [ApiInteractionVerificationSocialAuthorizationUriPostRequest](docs/ApiInteractionVerificationSocialAuthorizationUriPostRequest.md)
 - [ApiInteractionVerificationTotpPost200Response](docs/ApiInteractionVerificationTotpPost200Response.md)
 - [ApiInteractionVerificationVerificationCodePostRequest](docs/ApiInteractionVerificationVerificationCodePostRequest.md)
 - [ApiInteractionVerificationVerificationCodePostRequestOneOf](docs/ApiInteractionVerificationVerificationCodePostRequestOneOf.md)
 - [ApiInteractionVerificationVerificationCodePostRequestOneOf1](docs/ApiInteractionVerificationVerificationCodePostRequestOneOf1.md)
 - [ApiInteractionVerificationWebauthnAuthenticationPost200Response](docs/ApiInteractionVerificationWebauthnAuthenticationPost200Response.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200Response](docs/ApiInteractionVerificationWebauthnRegistrationPost200Response.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseAuthenticatorSelection](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseAuthenticatorSelection.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseExcludeCredentialsInner.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseExtensions.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponsePubKeyCredParamsInner](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponsePubKeyCredParamsInner.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseRp](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseRp.md)
 - [ApiInteractionVerificationWebauthnRegistrationPost200ResponseUser](docs/ApiInteractionVerificationWebauthnRegistrationPost200ResponseUser.md)
 - [ApiLogsGet200ResponseInner](docs/ApiLogsGet200ResponseInner.md)
 - [ApiLogsGet200ResponseInnerPayload](docs/ApiLogsGet200ResponseInnerPayload.md)
 - [ApiLogsGet200ResponseInnerPayloadError](docs/ApiLogsGet200ResponseInnerPayloadError.md)
 - [ApiOrganizationInvitationsIdStatusPutRequest](docs/ApiOrganizationInvitationsIdStatusPutRequest.md)
 - [ApiOrganizationInvitationsPostRequest](docs/ApiOrganizationInvitationsPostRequest.md)
 - [ApiOrganizationRolesGet200ResponseInner](docs/ApiOrganizationRolesGet200ResponseInner.md)
 - [ApiOrganizationRolesIdPatchRequest](docs/ApiOrganizationRolesIdPatchRequest.md)
 - [ApiOrganizationRolesIdResourceScopesPostRequest](docs/ApiOrganizationRolesIdResourceScopesPostRequest.md)
 - [ApiOrganizationRolesIdResourceScopesPutRequest](docs/ApiOrganizationRolesIdResourceScopesPutRequest.md)
 - [ApiOrganizationRolesIdScopesPostRequest](docs/ApiOrganizationRolesIdScopesPostRequest.md)
 - [ApiOrganizationRolesIdScopesPutRequest](docs/ApiOrganizationRolesIdScopesPutRequest.md)
 - [ApiOrganizationRolesPostRequest](docs/ApiOrganizationRolesPostRequest.md)
 - [ApiOrganizationScopesIdPatchRequest](docs/ApiOrganizationScopesIdPatchRequest.md)
 - [ApiOrganizationScopesPostRequest](docs/ApiOrganizationScopesPostRequest.md)
 - [ApiOrganizationsGet200ResponseInner](docs/ApiOrganizationsGet200ResponseInner.md)
 - [ApiOrganizationsIdPatchRequest](docs/ApiOrganizationsIdPatchRequest.md)
 - [ApiOrganizationsIdUsersGet200ResponseInner](docs/ApiOrganizationsIdUsersGet200ResponseInner.md)
 - [ApiOrganizationsIdUsersPostRequest](docs/ApiOrganizationsIdUsersPostRequest.md)
 - [ApiOrganizationsIdUsersPutRequest](docs/ApiOrganizationsIdUsersPutRequest.md)
 - [ApiOrganizationsIdUsersRolesPostRequest](docs/ApiOrganizationsIdUsersRolesPostRequest.md)
 - [ApiOrganizationsIdUsersUserIdRolesPostRequest](docs/ApiOrganizationsIdUsersUserIdRolesPostRequest.md)
 - [ApiOrganizationsIdUsersUserIdRolesPutRequest](docs/ApiOrganizationsIdUsersUserIdRolesPutRequest.md)
 - [ApiOrganizationsPostRequest](docs/ApiOrganizationsPostRequest.md)
 - [ApiResourcesGet200ResponseInner](docs/ApiResourcesGet200ResponseInner.md)
 - [ApiResourcesGet200ResponseInnerScopesInner](docs/ApiResourcesGet200ResponseInnerScopesInner.md)
 - [ApiResourcesIdIsDefaultPatchRequest](docs/ApiResourcesIdIsDefaultPatchRequest.md)
 - [ApiResourcesIdPatchRequest](docs/ApiResourcesIdPatchRequest.md)
 - [ApiResourcesPostRequest](docs/ApiResourcesPostRequest.md)
 - [ApiResourcesResourceIdScopesPostRequest](docs/ApiResourcesResourceIdScopesPostRequest.md)
 - [ApiResourcesResourceIdScopesScopeIdPatchRequest](docs/ApiResourcesResourceIdScopesScopeIdPatchRequest.md)
 - [ApiRolesGet200ResponseInner](docs/ApiRolesGet200ResponseInner.md)
 - [ApiRolesGet200ResponseInnerFeaturedApplicationsInner](docs/ApiRolesGet200ResponseInnerFeaturedApplicationsInner.md)
 - [ApiRolesGet200ResponseInnerFeaturedUsersInner](docs/ApiRolesGet200ResponseInnerFeaturedUsersInner.md)
 - [ApiRolesIdApplicationsPostRequest](docs/ApiRolesIdApplicationsPostRequest.md)
 - [ApiRolesIdPatchRequest](docs/ApiRolesIdPatchRequest.md)
 - [ApiRolesIdScopesGet200ResponseInner](docs/ApiRolesIdScopesGet200ResponseInner.md)
 - [ApiRolesIdScopesPostRequest](docs/ApiRolesIdScopesPostRequest.md)
 - [ApiRolesIdUsersPostRequest](docs/ApiRolesIdUsersPostRequest.md)
 - [ApiRolesPostRequest](docs/ApiRolesPostRequest.md)
 - [ApiSignInExpGet200Response](docs/ApiSignInExpGet200Response.md)
 - [ApiSignInExpGet200ResponseColor](docs/ApiSignInExpGet200ResponseColor.md)
 - [ApiSignInExpGet200ResponseLanguageInfo](docs/ApiSignInExpGet200ResponseLanguageInfo.md)
 - [ApiSignInExpGet200ResponseMfa](docs/ApiSignInExpGet200ResponseMfa.md)
 - [ApiSignInExpGet200ResponsePasswordPolicy](docs/ApiSignInExpGet200ResponsePasswordPolicy.md)
 - [ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes](docs/ApiSignInExpGet200ResponsePasswordPolicyCharacterTypes.md)
 - [ApiSignInExpGet200ResponsePasswordPolicyLength](docs/ApiSignInExpGet200ResponsePasswordPolicyLength.md)
 - [ApiSignInExpGet200ResponsePasswordPolicyRejects](docs/ApiSignInExpGet200ResponsePasswordPolicyRejects.md)
 - [ApiSignInExpGet200ResponseSignIn](docs/ApiSignInExpGet200ResponseSignIn.md)
 - [ApiSignInExpGet200ResponseSignInMethodsInner](docs/ApiSignInExpGet200ResponseSignInMethodsInner.md)
 - [ApiSignInExpGet200ResponseSignUp](docs/ApiSignInExpGet200ResponseSignUp.md)
 - [ApiSignInExpPatch200Response](docs/ApiSignInExpPatch200Response.md)
 - [ApiSignInExpPatch200ResponseColor](docs/ApiSignInExpPatch200ResponseColor.md)
 - [ApiSignInExpPatch200ResponseLanguageInfo](docs/ApiSignInExpPatch200ResponseLanguageInfo.md)
 - [ApiSignInExpPatch200ResponseMfa](docs/ApiSignInExpPatch200ResponseMfa.md)
 - [ApiSignInExpPatch200ResponsePasswordPolicy](docs/ApiSignInExpPatch200ResponsePasswordPolicy.md)
 - [ApiSignInExpPatch200ResponseSignIn](docs/ApiSignInExpPatch200ResponseSignIn.md)
 - [ApiSignInExpPatch200ResponseSignUp](docs/ApiSignInExpPatch200ResponseSignUp.md)
 - [ApiSignInExpPatchRequest](docs/ApiSignInExpPatchRequest.md)
 - [ApiSignInExpPatchRequestColor](docs/ApiSignInExpPatchRequestColor.md)
 - [ApiSignInExpPatchRequestLanguageInfo](docs/ApiSignInExpPatchRequestLanguageInfo.md)
 - [ApiSignInExpPatchRequestSignIn](docs/ApiSignInExpPatchRequestSignIn.md)
 - [ApiSignInExpPatchRequestSignUp](docs/ApiSignInExpPatchRequestSignUp.md)
 - [ApiSignInExpPatchRequestTermsOfUseUrl](docs/ApiSignInExpPatchRequestTermsOfUseUrl.md)
 - [ApiSsoConnectorProvidersGet200ResponseInner](docs/ApiSsoConnectorProvidersGet200ResponseInner.md)
 - [ApiSsoConnectorsGet200ResponseInner](docs/ApiSsoConnectorsGet200ResponseInner.md)
 - [ApiSsoConnectorsGet200ResponseInnerBranding](docs/ApiSsoConnectorsGet200ResponseInnerBranding.md)
 - [ApiSsoConnectorsIdPatchRequest](docs/ApiSsoConnectorsIdPatchRequest.md)
 - [ApiSsoConnectorsPost200Response](docs/ApiSsoConnectorsPost200Response.md)
 - [ApiSsoConnectorsPostRequest](docs/ApiSsoConnectorsPostRequest.md)
 - [ApiSystemsApplicationGet200Response](docs/ApiSystemsApplicationGet200Response.md)
 - [ApiSystemsApplicationGet200ResponseProtectedApps](docs/ApiSystemsApplicationGet200ResponseProtectedApps.md)
 - [ApiUserAssetsPost200Response](docs/ApiUserAssetsPost200Response.md)
 - [ApiUserAssetsServiceStatusGet200Response](docs/ApiUserAssetsServiceStatusGet200Response.md)
 - [ApiUserAssetsServiceStatusGet200ResponseStatus](docs/ApiUserAssetsServiceStatusGet200ResponseStatus.md)
 - [ApiUsersPostRequest](docs/ApiUsersPostRequest.md)
 - [ApiUsersUserIdCustomDataPatchRequest](docs/ApiUsersUserIdCustomDataPatchRequest.md)
 - [ApiUsersUserIdGet200Response](docs/ApiUsersUserIdGet200Response.md)
 - [ApiUsersUserIdGet200ResponseSsoIdentitiesInner](docs/ApiUsersUserIdGet200ResponseSsoIdentitiesInner.md)
 - [ApiUsersUserIdHasPasswordGet200Response](docs/ApiUsersUserIdHasPasswordGet200Response.md)
 - [ApiUsersUserIdIdentitiesPostRequest](docs/ApiUsersUserIdIdentitiesPostRequest.md)
 - [ApiUsersUserIdIdentitiesTargetPutRequest](docs/ApiUsersUserIdIdentitiesTargetPutRequest.md)
 - [ApiUsersUserIdIsSuspendedPatchRequest](docs/ApiUsersUserIdIsSuspendedPatchRequest.md)
 - [ApiUsersUserIdMfaVerificationsGet200ResponseInner](docs/ApiUsersUserIdMfaVerificationsGet200ResponseInner.md)
 - [ApiUsersUserIdMfaVerificationsPost200Response](docs/ApiUsersUserIdMfaVerificationsPost200Response.md)
 - [ApiUsersUserIdMfaVerificationsPost200ResponseOneOf](docs/ApiUsersUserIdMfaVerificationsPost200ResponseOneOf.md)
 - [ApiUsersUserIdMfaVerificationsPost200ResponseOneOf1](docs/ApiUsersUserIdMfaVerificationsPost200ResponseOneOf1.md)
 - [ApiUsersUserIdMfaVerificationsPostRequest](docs/ApiUsersUserIdMfaVerificationsPostRequest.md)
 - [ApiUsersUserIdMfaVerificationsPostRequestType](docs/ApiUsersUserIdMfaVerificationsPostRequestType.md)
 - [ApiUsersUserIdOrganizationsGet200ResponseInner](docs/ApiUsersUserIdOrganizationsGet200ResponseInner.md)
 - [ApiUsersUserIdOrganizationsGet200ResponseInnerOrganizationRolesInner](docs/ApiUsersUserIdOrganizationsGet200ResponseInnerOrganizationRolesInner.md)
 - [ApiUsersUserIdPasswordPatchRequest](docs/ApiUsersUserIdPasswordPatchRequest.md)
 - [ApiUsersUserIdPasswordVerifyPostRequest](docs/ApiUsersUserIdPasswordVerifyPostRequest.md)
 - [ApiUsersUserIdPatch200Response](docs/ApiUsersUserIdPatch200Response.md)
 - [ApiUsersUserIdPatchRequest](docs/ApiUsersUserIdPatchRequest.md)
 - [ApiUsersUserIdPatchRequestAvatar](docs/ApiUsersUserIdPatchRequestAvatar.md)
 - [ApiUsersUserIdPatchRequestName](docs/ApiUsersUserIdPatchRequestName.md)
 - [ApiUsersUserIdPatchRequestPrimaryEmail](docs/ApiUsersUserIdPatchRequestPrimaryEmail.md)
 - [ApiUsersUserIdPatchRequestPrimaryPhone](docs/ApiUsersUserIdPatchRequestPrimaryPhone.md)
 - [ApiUsersUserIdPatchRequestUsername](docs/ApiUsersUserIdPatchRequestUsername.md)
 - [ApiUsersUserIdProfilePatchRequest](docs/ApiUsersUserIdProfilePatchRequest.md)
 - [ApiUsersUserIdProfilePatchRequestProfile](docs/ApiUsersUserIdProfilePatchRequestProfile.md)
 - [ApiVerificationCodesVerifyPostRequest](docs/ApiVerificationCodesVerifyPostRequest.md)
 - [ApiWellKnownPhrasesGet200ResponseValue](docs/ApiWellKnownPhrasesGet200ResponseValue.md)
 - [ApiWellKnownSignInExpGet200Response](docs/ApiWellKnownSignInExpGet200Response.md)
 - [ApiWellKnownSignInExpGet200ResponseForgotPassword](docs/ApiWellKnownSignInExpGet200ResponseForgotPassword.md)
 - [ApiWellKnownSignInExpGet200ResponseSocialConnectorsInner](docs/ApiWellKnownSignInExpGet200ResponseSocialConnectorsInner.md)
 - [ApiWellKnownSignInExpGet200ResponseSsoConnectorsInner](docs/ApiWellKnownSignInExpGet200ResponseSsoConnectorsInner.md)
 - [Translation](docs/Translation.md)
 - [TranslationObject](docs/TranslationObject.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization

Endpoints do not require authorization.


## Author




